#!/usr/bin/perl
#################################################################Modules
use strict;
use warnings;
use Net::Dict;
use Tk::DialogBox;
use Tk::LabEntry;
use Tk::ROText;
use Tk::HList;
use Tk::Menu;
use Tk;
############################################################Declarations
our $VERSION = 1.60;
my (@wik, $dictRef,);
####################################################################Main
init();
gui();
Tk::MainLoop();
####################################################################Exit
warn "lexicon is exiting.\t(" . localtime(time) . ")\n";
close STDERR || warn "Cannot close log\n[$!]\n";
exit;
#############################################################Subroutines
sub init #--------------------------------------------------------------INIT
{
  #start logging
  open (STDERR, '>', 'lexicon.log') || warn "Can't create log\n[$!]\n";
  warn "lexicon has started.\t(" . localtime(time) . ")\n";
  
  #load optional modules
  if ($^O eq 'MSWin32') {
    eval    { require Win32::Console; Win32::Console::Free()   };
    if ($@) { warn "Win32::Console is not installed\n[$@]\n"; }
  }
  eval { require WWW::Wikipedia; };
  if (! $@) {
    $wik[0] = 1;
    eval { require HTML::FormatText::WithLinks };
    if (! $@) { $wik[1] = 1; }
  }
  else {
    warn "WWW::Wikipedia is not installed\n[$@]\n";
  }
  
  #load default server list if needed
  if (! -e 'servers.sl1') {
    if (open ('FH', '>', 'servers.sl1')) {
      print FH 'dict://dict.org' . '~::~' .
               'The standard dictd server, contains many ' .
               'interesting databases related various topics.' . "\n";
      print FH 'dict://dict.die.net' . '~::~' .
               'A dictd server with several databases.' . "\n";
    }
    else {
      warn "Error - Cannot create servers.sl1\n[$!]\n";
      menu_1_cmd('View Log');
    }
  }
  return (1);
}
sub gui #---------------------------------------------------------------
{
  #Main Window
  our ($mw, %widgets, $sys_bg, $sys_fg,);
  $mw = MainWindow->new(
    -title  => 'lexicon',
    -relief => 'groove',
    -bd     => 2,
  );
  $mw->gridRowconfigure(1,    -minsize => 8, -weight => 1,);
  $mw->gridColumnconfigure(1, -minsize => 8, -weight => 1,);
  $sys_bg = $mw->cget(-background);
  $sys_fg = $mw->cget(-foreground);
  
  #Splashscreen
  {
    my ($splash, $canvas, $image, $geometry, $sys_x, $sys_y,);
    $sys_x = $mw->screenwidth;
    $sys_y = $mw->screenheight;
    $mw->withdraw;
    {
      my $imagedata = load_image(1);
      $image = $mw->Photo(-format => 'gif', -data => $imagedata);
    }
    {
      my $x   = ($sys_x / 2) - 250;
      my $y   = ($sys_y / 2) - 144;
      $geometry = '500x288+' . $x . '+' .$y;
      $splash = $mw->Toplevel(-takefocus => 1,);
      $splash->overrideredirect(1);
      $splash->geometry($geometry);
      $splash->resizable(0, 0);
    }
    $canvas = $splash->Canvas()->pack(
      -fill   => 'both',
      -expand => 1,
    );
    $canvas->createImage(0,0,
      -image  => $image,
      -anchor => 'nw',
    );
    $mw->after(8000, sub {
      {
        my $w = $mw->width;
        my $h = $mw->height;
        my $x = int(($sys_x / 2) - ($w / 2));
        my $y = int(($sys_y / 2) - ($h / 2));
        $mw->geometry($w . 'x' . $h . '+' . $x . '+' . $y);
      }
      $splash->destroy;
      $mw->deiconify;
      $mw->raise;
    });
  }
  
  #Menubar
  my  ($menu_1,);
  our ($meni_1, $meni_2, $meni_3,);
  $menu_1 = $mw->Menu();
  $meni_1 = $mw->Menu(-tearoff => '0',);
  $meni_2 = $mw->Menu(-tearoff => '0',);
  $meni_3 = $mw->Menu(-tearoff => '0',);
  $menu_1->cascade(
    -label     => 'File',
    -underline => 0,
    -menu      => $meni_1,
  );
  $menu_1->cascade(
    -label     => 'Tools',
    -underline => 0,
    -menu      => $meni_2,
  );
  $menu_1->cascade(
    -label     => 'Help',
    -underline => 0,
    -menu      => $meni_3,
  );
  my $c = 0;
  foreach my $l (
    'Save', 'Exit', 'Add Server', 'Del Server', 'View Log', 'Clear Log',
    'Colors', 'Font +', 'Font -', 'Help', 'About'
  ) {
    $c++;
    if ($c < 3) {
      if ($l eq 'Exit') { $meni_1->separator(); }
      $meni_1->command(
        -label     => $l,
        -underline => '0',
        -command   => sub {
          menu_1_cmd($l);
        },
      );
    }
    elsif ($c < 10) {
      my $u = 0;
      if    ($l eq 'View Log') { $meni_2->separator();          }
      elsif ($l eq 'Colors')   { $meni_2->separator(); $u += 2; }
      elsif ($l =~ m/Font/ig)  { $u += 5                        }
      $meni_2->command(
        -label     => $l,
        -underline => $u,
        -command   => sub { menu_1_cmd($l);},
      );
    }
    else {
      $meni_3->command(
        -label     => $l,
        -underline => '0',
        -command   => sub { menu_1_cmd($l); },
      );
    }
  }
  $mw->configure(-menu => $menu_1,);
  undef $c;
  
  #Frames
  my ($f3, $f4, $f5, $f2, $f1,);
  $f1 = $mw->Frame(-relief => 'flat', -bd => 2,)->grid(
    -in   => $mw, -column => 1, -row    => 1,
    -padx => 4,   -pady   => 4, -sticky => 'news',
  );
  $f2 = $mw->Frame(-relief => 'flat',   -bd => 2,)->grid(
    -in => $mw, -column => 1, -row => 2, -sticky => 'news',
  );
  $f3 = $f1->Frame(-relief => 'sunken', -bd => 1,)->grid(
    -in => $f1, -column => 1, -row => 1, -sticky => 'news',
  );
  $f4 = $f1->Frame(-relief => 'sunken', -bd => 1,)->grid(
    -in => $f1, -column => 1, -row => 2,
    -pady => 4, -sticky => 'news',
  );
  $f5 = $f1->Frame(-relief => 'sunken', -bd => 2,)->grid(
    -in => $f1, -column => 1, -row => 3, -sticky => 'news',
  );
  $f1->gridRowconfigure(3,    -minsize => 8, -weight => 1);
  $f1->gridColumnconfigure(1, -minsize => 8, -weight => 1);
  $f3->gridColumnconfigure(2, -minsize => 8, -weight => 1);
  $f4->gridColumnconfigure(1, -minsize => 8, -weight => 1);
  $f5->gridRowconfigure(1,    -minsize => 8, -weight => 1);
  $f5->gridColumnconfigure(1, -minsize => 8, -weight => 1);
  
  #Check buttons
  our($cb1_var, $cb2_var, $cb3_var,);
  {
    $f2->Checkbutton(-variable => \$cb1_var, -command => sub {},)->grid(
      -in => $f2, -row => 1, -column => 2, -sticky => 'news',
    );
    #$f2->Checkbutton(-variable => \$cb2_var, -command => sub {},)->grid(
    #  -in => $f2, -row => 1, -column => 4, -sticky => 'news',
    #);
    $f2->gridColumnconfigure(4, -weight => 1,);
    $c = 1;
    foreach my $l (
      '  Additional search tools:  ',
      'Wikipedia.com      ',
    ) {
      $f2->Label(
        -text   => $l,
        -anchor => 'w',
      )->grid(
        -in => $f2, -row => 1, -column => $c, -sticky => 'news',
      );
      $c += 2;
    }
  }
  
  #Labels
  our @labels;
  {
    my $c = 1;
    foreach my $l ('Server:', 'Database:', 'Search For:') {
      my $w = $f3->Label(
        -text   => $l,
        -anchor => 'w',
        -relief => 'solid',
        -width  => 10,
        -bd     => .5
      )->grid(
        -in => $f3, -column => 1, -row => $c, -sticky => 'news'
      );
      push (@labels, $w);
      $c++;
    }
  }
  
  #Entries
  our @entries;
  {
    my $c = 1;
    foreach my $l qw(readonly readonly normal) {
      my $w = $f3->Entry(
        -state              => $l,
        -fg                 => '#000000',
        -bg                 => '#ffffff',
        -readonlybackground => '#ffffff',
        -relief             => 'sunken',
        -bd                 => 2,
      )->grid(
        -in => $f3, -row => $c, -column => 2, -sticky => 'news',
      );
      if ($l eq 'normal') {
        $w->grid(-columnspan => 2,);
        $w->bind('<ButtonRelease-3>' => \&menu2);
        $w->bind('<Return>'          => \&submit);
      }
      push (@entries, $w);
      $c++;
    }
  }
  
  #Buttons
  our @buttons;
  {
    $c = 1;
    foreach my $l ('list_servers', 'list_databases',) {
      my $sub = \&{ $l; };
      my $w = $f3->Button(
        -activeforeground => '#fff000',
        -relief           => 'solid',
        -bitmap           => '@'.Tk->findINC('cbxarrow.xbm'),
        -height           => 10,
        -bd               => .5,
        -command          => sub { &$sub(1); },
      )->grid(
        -in => $f3, -row => $c, -column => 3, -sticky => 'nsw',
      );
      push (@buttons, $w);
      $c++;
    }
    my $w = $f4->Button(
      -text             => 'Submit Query',
      -state            => 'disabled',
      -activeforeground => '#0000ff',
      -relief           => 'raised',
      -bd               => 3,
      -command          => sub { submit(); },
    )->grid(
      -in => $f4, -row => 1, -column => 1, -sticky => 'news',
    );
    push (@buttons, $w);
  }
  
  #Text widgets
  our $t1 = $f5->Scrolled(
    'ROText',
    -bd               => 2,
    -width            => 80,
    -scrollbars       => 'e',
    -relief           => 'flat',
    -wrap             => 'word',
    -bg               => '#ffffff',
    -fg               => '#000000',
    -insertbackground => '#ffffff',
    -selectforeground => '#fff000',
    -selectbackground => '#000000',
  )->grid(
      -in => $f5, -row => 1, -column => 1, -sticky => 'news',
  );
  {
    my $t1_menu;
    $t1_menu = $t1->menu;
    $t1_menu->delete('File');
    $t1_menu->delete('View');
    $t1_menu->delete('Search');
    $t1_menu->configure(-bg => $sys_bg, -fg => $sys_fg,);
    $t1->tagConfigure('Bold', -font       => 'Courier 10 bold');
    $t1->tagConfigure('Blue', -foreground => '#000fff');
    $t1->tagConfigure('Red',  -foreground => '#ff0000');
  }
  
  #Choose server window
  our ($tl1, $f3_srv, $hl_srv,);
  {
    $tl1 = $mw->Toplevel(-relief => 'flat',);
    $tl1->overrideredirect(1);
    $tl1->resizable(0, 0);
    $tl1->transient($mw);
    $tl1->withdraw;
    
    $f3_srv = $tl1->Frame(
      -relief    => 'groove',
      -takefocus => 1,
      -bd        => 2,
    )->pack();
    $hl_srv = $f3_srv->Scrolled(
      'HList',
      -header           => 1,
      -columns          => 2,
      -height           => 8,
      -width            => 90,
      -scrollbars       => 'osoe',
      -selectmode       => 'single',
      -bg               => '#000000',
      -fg               => '#ffffff',
      -selectforeground => '#000000',
      -selectbackground => '#fff000',)->pack(
    );
    $hl_srv->columnWidth(0, -char => '30');
    $hl_srv->columnWidth(1, -char => '');
    $hl_srv->header(
      'create', 0,
      -borderwidth => 1,
      -text        => 'Server',
    );
    $hl_srv->header(
      'create', 1,
      -borderwidth => 1,
      -text        => 'Description',
    );
  }
  
  #Choose database window
  our ($tl2, $f3_dbs, $hl_dbs,);
  {
    $tl2 = $mw->Toplevel(-relief => 'flat',);
    $tl2->overrideredirect(1);
    $tl2->resizable(0, 0);
    $tl2->transient($mw);
    $tl2->withdraw;
  
    $f3_dbs = $tl2->Frame(
      -relief    => 'groove',
      -takefocus => 1,
      -bd        => 2,)->pack(
    );
    $hl_dbs = $f3_dbs->Scrolled(
      'HList',
      -header           => 1,
      -columns          => 2,
      -height           => 8,
      -width            => 90,
      -scrollbars       => 'osoe',
      -selectmode       => 'extended',
      -bg               => '#000000',
      -fg               => '#ffffff',
      -selectforeground => '#000000',
      -selectbackground => '#fff000',)->pack(
    );
    $hl_dbs->columnWidth(0, -char => '75');
    $hl_dbs->columnWidth(1, -char => '');
    $hl_dbs->header(
      'create', 0,
      -borderwidth => 1,
      -text        => 'Database',
    );
    $hl_dbs->header(
      'create', 1,
      -borderwidth => 1,
    );
  }
  
  #RC Menu 1
  our $tl3;
  {
    my ($f, $b,);
    $tl3 = $mw->Toplevel(
      -relief    => 'raised',
      -takefocus => 1,
      -bd        => 2,
    );
    $tl3->overrideredirect(1);
    $tl3->resizable(0, 0);
    $tl3->transient($mw);
    $tl3->withdraw;
    
    $f = $tl3->Frame(
      -relief    => 'sunken',
      -takefocus => 1,
      -bd        => 1,)->pack(
    );
    $b = $f->Button(
      -text             => 'Add Selected',
      -relief           => 'flat',
      -anchor           => 'w',
      -activeforeground => '#fff000',
      -command          => sub{ dbs_sel(); },)->pack(
    );
    FlashButton($b, 'green', '#000000');
  }
  
  #RC Menu 2
  our ($tl4,);
  {
    my ($f, $b,);
    $tl4 = $mw->Toplevel(
      -relief    => 'raised',
      -takefocus => 1,
      -bd        => 2,
    );
    $tl4->overrideredirect(1);
    $tl4->resizable(0, 0);
    $tl4->transient($mw);
    $tl4->withdraw;
    
    $f = $tl4->Frame(
      -relief    => 'sunken',
      -takefocus => 1,
      -bd        => 1,)->pack(
    );
    $b = $f->Button(
      -text             => 'Paste',
      -relief           => 'flat',
      -anchor           => 'w',
      -activeforeground => '#fff000',
      -command          => \&menu2_cmd)->pack(
    );
    FlashButton($b, 'green', '#000000');
  }
  
  #Bindings
  $mw->bind('<F1>'                  => sub { menu_1_cmd('Help');   });
  $mw->bind('<Control-Key-plus>'    => sub { menu_1_cmd('Font +'); });
  $mw->bind('<Control-KP_Add>'      => sub { menu_1_cmd('Font +'); });
  $mw->bind('<Control-Key-minus>'   => sub { menu_1_cmd('Font -'); });
  $mw->bind('<Control-KP_Subtract>' => sub { menu_1_cmd('Font -'); });
  $f3_srv->bind('<FocusOut>' => sub { $tl1->withdraw; });
  $f3_dbs->bind('<FocusOut>' => sub { $tl2->withdraw; });
  $tl3   ->bind('<FocusOut>' => sub { $tl3->withdraw; });
  $tl4   ->bind('<FocusOut>' => sub { $tl4->withdraw; });
  $hl_srv->bind('<Double-Button-1>' => \&srv_sel);
  $hl_dbs->bind('<Double-Button-1>' => \&dbs_sel);
  $hl_dbs->bind('<ButtonRelease-3>' => \&menu1);
  
  #Defaults
  
  #Callbacks
  sub menu_1_cmd #------------------------------------------------------MENU COMMANDS
  {
    my $x = $_[0];
    my $y = $_[1];
    my $z = $_[2];
    $mw->Busy(-recurse => 1);
    
    if ($x eq 'Save') {                                            #save
      my $t = $t1->get('1.0', 'end');
      if($t =~/.+/) {
        my $sf = $mw->getSaveFile();
        if ($sf) {
          if (open ('FH', '>', $sf)) {
            print FH $t;
            close FH
              || warn "Error - Can't close $sf\n[$!]\n";;
          }
          else {
            warn "Error - Can't create $sf\n[$!]\n";
          }
        }
      }
    }
    elsif ($x eq 'Add Server') {                             #add server
      my $db = $mw->DialogBox(
        -title          => 'Add Server',
        -buttons        => ['Add', 'Cancel'],
        -default_button => 'Cancel',
      );
      $db->add(
        'LabEntry',
        -label        => 'URL:          ',
        -textvariable => \my $url,
        -background   => '#ffffff',
        -foreground   => '#000000',
        -width        => 60,
        -labelPack    => [-side   => 'left',])->pack(
      );
      $db->add(
        'LabEntry',
        -label        => 'Description:',
        -textvariable => \my $desc,
        -background   => '#ffffff',
        -foreground   => '#000000',
        -width        => 60,
        -labelPack    => [-side   => 'left',])->pack(
      );
      
      my $ans = $db->Show();
      if ($ans eq 'Add' && $url) {
        unless ($desc) { $desc = 'No description'; }
        if ($url =~ /[\+\?\*\^\$]+/) {
          warn 'Error - Cannot add server: (' . $url . ")\n";
          menu_1_cmd('View Log');
        }
        else {
          open ('FH', '>>', 'servers.sl1')
            or warn "Error - Cannot append servers.sl1\n$!\n";
          print FH $url . '~::~' . $desc . "\n";
          close FH;
        }
      }
    }
    elsif ($x eq 'Del Server') {                             #del server
      my $db = $mw->DialogBox(
        -title          => 'Delete Server',
        -buttons        => ['Delete', 'Cancel'],
        -default_button => 'Cancel'
      );
      my $hl = $db->add(
        'Scrolled', 'HList',
        -header           => 1,
        -columns          => 2,
        -height           => 8,
        -width            => 90,
        -scrollbars       => 'osoe',
        -selectmode       => 'single',
        -bg               => '#ffffff',
        -fg               => '#000000',
        -selectforeground => '#fff000',
        -selectbackground => '#000000',
      )->pack();
      $hl->columnWidth(0, -char => '30');
      $hl->columnWidth(1, -char => '');
      $hl->header(
        'create', 0,
        -borderwidth => 1,
        -text        => 'Server',
      );
      $hl->header(
        'create', 1,
        -borderwidth => 1,
        -text        => 'Description',
      );
      
      #read server list into listbox
      {
        my $i = 0;
        open ('FH', '<', 'servers.sl1')
          || warn "Error - Cannot open servers.sl1\n[$!]\n";
        while (my $l = (<FH>)) {
          chomp $l;
          my @srv = split('~::~', $l);
          $hl->add($i);
          $hl->itemCreate($i, 0, -text => $srv[0]);
          $hl->itemCreate($i, 1, -text => $srv[1]);
          $i++;
        }
        close FH
          || warn "Error - Can't close servers.sl1\n[$!]\n";
      }
      
      #Delete or Cancel
      my $ans = $db->Show();
      my @sel = $hl->selectionGet;
      if ($ans eq 'Delete' && $sel[0]) {
        #delete selected server from server list
        my $server = $hl->itemCget($sel[0], 0, -text);
        if (rename ('servers.sl1', 'servers.sl1.tmp')) {
          if (open ('IN', '<', 'servers.sl1.tmp')) {
            if (open ('OUT', '>', 'servers.sl1')) {
              while (my $l = (<IN>)) {
                chomp $l;
                if ($l =~ m/^$server~::~.*/) { next; }
                else                         { print OUT $l . "\n"; }
              }
              close OUT
                || warn "Error - Can't close servers.sl1\n[$!]\n";
            }
            else {
              warn "Error - Can't write to servers.sl1\n[$!]\n";
            }
            close IN
              || warn "Error - Can't close servers.sl1.tmp\n[$!]\n";
          }
          else {
            warn "Error - Can't read servers.sl1.tmp\n[$!]\n";
          }
          unlink 'servers.sl1.tmp'
            || warn "Error - Can't delete servers.sl1.tmp\n[$!]\n"
        }
        else {
          warn "Error - Can't rename servers.sl1\n[$!]\n";
        }
      }
      else {
        #cancel
      }
    }
    elsif ($x eq 'View Log') {                                 #view log
      $t1->delete('1.0', 'end');
      if (open ('FH', '<', 'lexicon.log')) {
        while (my $l = (<FH>)) {
          chomp $l;
          $l =~ s/^Net.*\)(<|>.*)/$1/;
          if ($l =~ m/^>>>.*/) {
            $t1->insert('end', $l . "\n", 'Blue');
          }
          elsif ($l =~ m/Error\s-\s.+/) {
            $t1->insert('end', $l . "\n", 'Red');
          }
          else {
            $t1->insert('end', $l . "\n");
          }
        }
        close FH
          || warn "Error - Can't close lexicon.log\n[$!]\n";
      }
      else {
        warn "Error - Can't open lexicon.log\n[$!]\n";
      }
      $mw->update;
    }
    elsif ($x eq 'Clear Log') {                               #clear log
      open ('FH', '>', 'lexicon.log')
        || warn "Error - Can't clear log.\n";
      print FH "Log cleared.\t(" . localtime() . ")\n";
      close FH
        || warn "Error - Can't close lexicon.log\n[$!]\n";
      menu_1_cmd('View Log');
      $x = 'Clear Log';
    }
    elsif ($x eq 'Colors') {                                     #colors
      $t1->delete('1.0', 'end');
      $mw->update;
      my $w;
      $w = $t1->Button(
        -text             => 'Color1',
        -activeforeground => '#fff000',
        -command          => sub {
          no warnings('all');
          $mw->configure(-bg => $sys_bg,);
          $t1->configure(-bg => '#ffffff', -fg => '#000000',);
          set_colors('#ffffff', $sys_bg, '#000000', $sys_fg,);
          use warnings('all');
          $mw->update;
        },
      )->pack();
      $t1->windowCreate('end', -window => $w);
      $t1->insert('end', "    ");
      $w = $t1->Button(
        -text             => 'Color2',
        -activeforeground => '#fff000',
        -command          => sub {
          $mw->configure(-bg => '#000f80',);
          $t1->configure(-bg => '#006080', -fg => '#ffffff');
          set_colors('#efefff', '#005080', '#000000', '#ffffff',);
        },
      )->pack();
      $t1->windowCreate('end', -window => $w);
      $t1->insert('end',"    ");
      $w = $t1->Button(
        -text => 'Color3',
        -activeforeground => '#fff000',
        -command => sub {
          $mw->configure(-bg => '#800f00',);
          $t1->configure(-bg => '#000000', -fg => '#ff2000',);
          set_colors('#000000', '#600000', '#ff2000', '#ffefef',);
        },
      )->pack();
      $t1->windowCreate('end', -window => $w);
      $t1->insert('end',"    ");
      $w = $t1->Button(
        -text             => 'Color4',
        -activeforeground => '#fff000',
        -command          => sub {
          $mw->configure(-bg => '#000000',);
          $t1->configure(-bg => '#404040', -fg => '#ffffff',);
          set_colors(
            '#101010', '#808080',
            '#ffffff', '#ffffff',
            '#000000', '#ffffff',
          );
        },
      )->pack();
      $t1->windowCreate('end', -window => $w);
      $t1->insert('end',"    ");
      $w = $t1->Button(
        -text             => 'Color5',
        -activeforeground => '#fff000',
        -command          => sub {
          no warnings('all');
          $mw->configure(-bg => $sys_bg,);
          $t1->configure(-bg => '#ffffff', -fg => '#000000',);
          set_colors(
            '#ffffff', $sys_bg,
            '#000000', $sys_fg,
            '#ffffff', '#000000',
          );
          use warnings('all');
        },
      )->pack();
      $t1->windowCreate('end', -window => $w);
      $t1->insert('end', "\n\n");
    }                                                              #todo-improve font
    elsif ($x eq 'Font +') {                                      #font+
      my $big = 18;
      $t1->configure(-font => 'Courier ' . $big);
    }
    elsif ($x eq 'Font -') {                                      #font-
      my $small = 10;
      $t1->configure(-font => 'Courier ' . $small);
    }
    elsif ($x eq 'Help') {                                         #help
      $t1->delete('1.0', 'end');
      $t1->insert('end',
        'lexicon is a utility which connects '.
        'to dictionary servers on the internet, '."\n"         .
        'Once connected you can lookup: definitions, prefix '  .
        "matches, and suffix matches.\n\n"                     .
        "First select a server from the 'Server' menu, after " .
        'double-clicking on an entry from this menu, an '      .
        'attempt will be made to connect to the selected '     .
        "server.\n\nNext select a database from the 'Database'".
        ' menu, if no database is selected all databases will '.
        "be searched.\n\nNow enter a term in the 'Search For' ".
        "field, then click on the 'Submit Query' button "      .
        "to preform the lookup.\n\nMatch searching works by "  .
        "entering a term followed or preceded by a '*'.\n"     .
        "Examples: alpha* or *bet"
      );
    }
    elsif ($x eq 'About') {                                       #about
      $t1->delete('1.0', 'end');
      $t1->insert(
        'end',
        "lexicon\n\n".
        "Version:   1.60\n".
        "Author:    Jason McManus\n".
        'Contact:   QoS@cpan.org'."\n"
      );
    }
    elsif ($x eq 'Exit') {                                         #exit
      $mw->Busy(-recurse => 1);
      exit;
    }
    else {
      die 'Invalid option:  [' . $x. "]\n";
    }
    $mw->Unbusy;
    $mw->update;
    return (1);
  }
  sub dictConnect #- ---------------------------------------------------CONNECT
  {
    my $server = $_[0] || return (0);
    my ($dictObj,);
    
    if ($dictRef && $$dictRef->serverInfo) {
      #already connected
      return (1);
    }
    
    $dictObj = Net::Dict->new(
      $server,
      Debug  => 1,
      Client => 'Net::Dict (lex.i.con ' . $VERSION . ')',
    );
    if (! $dictObj) {
      warn 'Error - Cannot connect to (' . $server . ")\n[$@]\n";
      menu_1_cmd('View Log');
      return (0);
    }
    warn 'Connected to ' . $server . ' (' . localtime(time) . ")\n";
    return (\$dictObj);
  }
  sub list_servers #----------------------------------------------------LIST SERVERS
  {
    $mw->Busy(-recurse => 1);
    my $w = $tl1->reqwidth;
    my $h = $buttons[0]->height;
    my $x = ($buttons[0]->rootx) - $w;
    my $y = ($buttons[0]->rooty) + $h;
    $tl1->geometry('+' . $x . '+' . $y);
    $tl1->deiconify();
    $tl1->raise();
    $f3_srv->focus;
    $hl_srv->delete('all');
    
    if (open ('FH', '<', 'servers.sl1')) {
      my $i = 0;
      while (my $l = (<FH>)) {
        chomp $l;
        my @srv = split('~::~', $l);
        $hl_srv->add($i);
        $hl_srv->itemCreate($i, 0, -text => $srv[0]);
        $hl_srv->itemCreate($i, 1, -text => $srv[1]);
        $i++;
      }
      close FH
        || warn "Error - Can't close servers.sl1\n[$!]\n";
    }
    else {
      warn "Error - Can't open servers.sl1\n[$!]\n";
    }
    $mw->update;
    $mw->Unbusy;
    return (1);
  }
  sub list_databases #--------------------------------------------------LIST DATABASES
  {
    my ($serv,);
    $mw->Busy(-recurse => 1);
    $mw->update;
    
    #raise db selection window
    {
      my $w = $tl2->reqwidth;
      my $h = $buttons[1]->height;
      my $x = ($buttons[1]->rootx) - $w;
      my $y = ($buttons[1]->rooty) + $h;
      $tl2->geometry('+' . $x . '+' . $y);
      $tl2->deiconify();
      $tl2->raise();
      $f3_dbs->focus;
      $hl_dbs->delete('all');
    }
    
    #determine server
    $serv = $entries[0]->get();
    
    #connect to server
    $dictRef = dictConnect($serv);
    if ($dictRef) {
      #add default searches
      $hl_dbs->add('all');
      $hl_dbs->itemCreate('all', 0, -text => 'All');
      $hl_dbs->itemCreate('all', 1, -text => '*');
      $hl_dbs->add('1st');
      $hl_dbs->itemCreate('1st', 0, -text => 'First Match');
      $hl_dbs->itemCreate('1st', 1, -text => '!');
      
      #query server for database list, add additional searches
      my $i = 0;
      my %dbs = $$dictRef->dbs();
      if (%dbs) {
        while (my ($db, $title) = each %dbs) {
          $hl_dbs->add($i);
          $hl_dbs->itemCreate($i, 0, -text => $title);
          $hl_dbs->itemCreate($i, 1, -text => $db);
          $i++;
        }
      }
      else {
        warn "Error - Unable to query server for database list\n";
      }
      $$dictRef->quit;
    }
    else {
      warn 'Error - Unable to connect to server: [' . $serv . "]\n";
    }
    $mw->update;
    $mw->Unbusy;
    return (1);
  }
  sub srv_sel #---------------------------------------------------------SELECT SERVER
  {
    my (@sel, $server,);
    $mw->Busy(-recurse => 1);
    {
      @sel    = $hl_srv->selectionGet;
      $server = $hl_srv->itemCget($sel[0], 0, -text);
      $server =~ s#^dict:\/\/(.*)#$1#i;
      $entries[0]->configure(-state => 'normal');
      $entries[0]->delete(0, 'end');
      $entries[0]->insert('end', $server);
      $entries[0]->configure(-state => 'readonly');
      $entries[0]->focus;
    }
    $mw->update;
    $mw->Unbusy;
    return (1);
  }
  sub dbs_sel #---------------------------------------------------------SELECT DB
  {
    my @sel = $hl_dbs->selectionGet;
    $mw->Busy(-recurse => 1);
    $entries[1]->configure(-state => 'normal');
    $entries[1]->delete(0, 'end');
    $entries[1]->focus;
    foreach my $i (@sel) {
      my $title = $hl_dbs->itemCget($i, 0, -text);
      my $db    = $hl_dbs->itemCget($i, 1, -text);
      $entries[1]->insert('end', $db . ' ');
      $buttons[2]->configure(-state => 'normal');
      $mw->update;
    }
    $entries[1]->configure(-state => 'readonly');
    $mw->Unbusy;
    $mw->update;
    return (1);
  }
  sub submit #----------------------------------------------------------SUBMIT
  {
    my($aref, $serv, $srch, $term, @dbs,);
    
    #gather query information from entries
    $serv = $entries[0]->get();
    $srch = $entries[1]->get();
    $term = $entries[2]->get();
    if (! defined $serv || ! defined $srch || ! defined $term) {
      return (0);
    }
    
    #connect to server
    $mw->Busy(-recurse => 1);
    $t1->delete('1.0', 'end');
    $dictRef = dictConnect($serv);
    if (! $dictRef) {
      $buttons[0]->configure(-state => 'disabled');
      warn "Error - Could not connect to: [" . $serv . "]\n";
      menu_1_cmd('View Log');
      $mw->Unbusy;
      return (0);
    }
    
    #choose database
    @dbs = split (' ', $srch);
    if (! defined $dbs[0]) {
      $dbs[0] = '*';
    }
    
    #perform search                                                #todo - add more search capability
    $$dictRef->setDicts(@dbs);
    if ($term =~ /^\*(.*)/) {                             #suffix search
      $aref = $$dictRef->match($1, 'suffix');
    }
    elsif ($term =~ /(.*)\*$/) {                          #prefix search
      $aref = $$dictRef->match($1, 'prefix');
    }
    else {                                            #dictionary search
      $aref = $$dictRef->define($term);
    }
    
    #Check and display results
    if (defined @{$aref}[0]) {
      my $c = 0;
      foreach my $i (@{$aref}) {
        my ($dbname, $def) = @{$i};
        unless ($def)    { next;                }
        unless ($dbname) { $dbname = 'Unknown'; }
        $t1->insert('end', "<<Database: " . $dbname . ">>\n", 'Bold');
        $t1->insert('end', $def . "\n\n");
        if ($c >= 10)    { $mw->update; $c = 0; }
        else             { $c++;                }
      }
    }
    else {
      $t1->insert('end', "No matches.\n");
    }
    
    #disconnect
    $$dictRef->quit;
    
    #perform additional searches
    if ($cb1_var) {
      #wikipedia search requested
      warn "Wikipedia search requested\n";
      
      #determine if modules are installed and loaded
      if ($wik[0]) {
        my ($wiki, $entry, $txt,);
        warn "Performing Wikipedia search for: [" . $term . "]\n";
        $txt = '-'x80 . "\n" . 'Wikipedia Search' . "\n" . '-'x80;
        $t1->insert('end', $txt . "\n");
        
        $wiki = WWW::Wikipedia->new(
          -language => 'en',
          -timeout  => 2,
        );
        $entry = $wiki->search( $term );
        if ($entry) {
          my ($raw, $txt,);
          my $f = HTML::FormatText::WithLinks->new();
          $txt  = $entry->text();
          if ($wik[1]) {
            $txt = join ("\n", split ('\*', $f->parse($txt)));
          }
          else {
            warn "HTML::FormatText::WithLinks is not installed\n";
            $txt = join ("\n", split ('\*', $txt));
          }
          $t1->insert('end', $txt . "\n");
        }
        else {
          my $err = $wiki->error();
          warn "Error during wikipedia search\n" . $err . "\n[$!]\n";
        }
        $mw->update;
      }
    }
    if ($cb2_var) {
      #removed
    }
    $t1->focus;
    $mw->Unbusy;
    $mw->update;
    return (1);
  }
  sub menu1 #-----------------------------------------------------------MENU1
  {
    my ($x, $y) = $mw->pointerxy;
    $tl3->geometry('+'."$x".'+'."$y");
    $tl3->deiconify();
    $tl3->raise();
    $mw->update;
    return (1);
  }
  sub menu2 #-----------------------------------------------------------MENU2
  {
    my ($x, $y) = $mw->pointerxy;
    $tl4->geometry('+'."$x".'+'."$y");
    $tl4->deiconify();
    $tl4->raise();
    $tl4->focus;
    $mw->update;
    return (1);
  }
  sub menu2_cmd #-------------------------------------------------------MENU2 CMD
  {
    my $cb;
    eval {
      $mw->Busy(-recurse => 1);
      $cb = $mw->SelectionGet(-selection => 'CLIPBOARD')
    };
    if ($cb){
      $entries[2]->insert('end', $cb);
    }
    $entries[2]->focus;
    $mw->update;
    $mw->Unbusy;
    return (1);
  }
  sub set_colors #------------------------------------------------------   ToDo
  {
    my $bg1 = $_[0];
    my $bg2 = $_[1];
    my $fg1 = $_[2];
    my $fg2 = $_[3]; 
    my $bg3 = $_[4] || $bg2;
    my $fg3 = $_[5] || $fg2;
    
    $meni_1->configure (-bg => $bg3, -fg => $fg3,);
    $meni_2->configure (-bg => $bg3, -fg => $fg3,);
    $meni_3->configure (-bg => $bg3, -fg => $fg3,);
    foreach my $e (@entries) {
      $e->configure(
        -bg                 => $bg1,
        -fg                 => $fg1,
        -insertbackground   => $fg2,
        -readonlybackground => $bg1,
      );
    }
    foreach my $l (@labels) {
      $l->configure(-bg => $bg2, -fg => $fg2,);
    }
    foreach my $b (@buttons) {
      $b->configure(
        -bg               => $bg2,
        -fg               => $fg2,
        -activebackground => $bg2,
      );
    }
    {
      my $txtmenu = $t1->Menu;
      $txtmenu->configure(
        -bg => $sys_bg,
        -fg => $sys_fg,
      );
    }
    $t1->delete('1.0', 'end');
    $mw->update;
    return (1);
  }
  sub FlashButton #---------------------------------------------------
  {
    my $w  = $_[0] || return (0);
    my $c1 = $_[1] || return (0);
    my $c2 = $_[2] || return (0);
    
    $w->bind('<ButtonPress-1>' => sub {
      $w->configure(-relief => 'flat',);
      $w->configure(-fg => $c1);
      $w->flash;
      $w->flash;
      $w->configure(-fg => $c2);
    });
    return (1);
  }
  sub load_image #------------------------------------------------------LOAD IMAGE
  {
    my $opt = $_[0] || return (0);
    my $imagedata;
    
    if ($opt == 1) {
      while (my $l = (<DATA>)) { $imagedata .= $l; }
    }
    return ($imagedata);
  }
  return (1);
}
###########################################################DOCUMENTATION

#POD Section#
=head1 NAME

lexicon

=head1 DESCRIPTION

Navigate and interact with Dictionary servers.

=head1 README

lexicon - GUI based Dictionary Server browser.

Connects to and interacts with dictionary servers on the internet.
In addition this version may perform additional searches for the term.

=head1 PREREQUISITES

Net::Dict

Tk

=head1 COREQUISITES

Win32::Console (optional)
WWW::Wikipedia (optional)
HTML::FormatText::WithLinks (optional)

=head1 History

v1_0  (Sept. 2004)

      Initial release

v1_1

      Added a right-click menu to the 'Search For' entry
      Changed the 'server' and 'database' fields to 'readonly'

v1_2

      Fixed a bug with the submit button
      Minor GUI improvements

v1_4

      Started to add display options to the program

v1_5

      POD updates
      Fixed bug with 'Submit Query' button becoming enabled too soon

v1_51

      Added resizable fonts
      Changed splash screen load routine
      Updated servers list

v1_60 (Nov. 2008)

      Cleaned up code
      Restructured gui
      Improved color selection routines
      Included new search tools

=head1 ToDo

      *Add more default servers
      *Improve resizable fonts

=head1 Copyright

lexicon
Copyright (C) 2004 - 2008 Jason David McManus

This program is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 2 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

=pod OSNAMES

=pod SCRIPT CATEGORIES

Networking

=cut

__DATA__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